Examples
==========

You can find the interactive Jupyter notebook versions of these at the
`project repository <https://github.com/egemenimre/satmad/tree/master/docs/examples>`_.

Tutorials
---------
.. toctree::
    :maxdepth: 1

    examples/tutorials/satmad_first_steps.ipynb
    examples/tutorials/sso_analysis.ipynb

Analyses
---------
.. toctree::
    :maxdepth: 1

    examples/analysis/num_prop_performance_1.ipynb
    examples/analysis/num_prop_performance_2.ipynb
    examples/analysis/num_prop_performance_3.ipynb